@@ -624,7 +624,11 @@ static int __kcapi ctr_info (
 \*---------------------------------------------------------------------------*/
 static int ctr_proc_open(struct inode *inode, struct file *file)
 {
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0)
        return single_open(file, ctr_info, PDE(inode)->data);
+#else
+       return single_open(file, ctr_info, PDE_DATA(inode));
+#endif
 }
 
 const struct file_operations ctr_proc_fops = {
