@@ -548,11 +548,8 @@ static int cs_event(event_t event, int priority, event_callback_args_t *args)
 } /* cs_event */
 
 static struct pcmcia_driver cs_driver = {
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,15)
-	.owner	= THIS_MODULE,
-#endif
-	.drv	= {
-		.name	= "fcpcmcia_cs",
+	.drv = {
+		.name = "fcpcmcia_cs",
 	},
 	.attach	= cs_attach,
 	.detach	= cs_detach,
