@@ -48,6 +48,12 @@
 #include "lib.h"
 #include "defs.h"
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)
+#define __devinit
+#define __devexit
+#define __devexit_p
+#endif
+
 MODULE_LICENSE ("Proprietary");
 MODULE_DESCRIPTION ("CAPI4Linux: Driver for " PRODUCT_LOGO);
 
